==> whiteboard_core-1.0.0-rc.0.tar.gz: lib/src/model/whiteboard_login_info.dart <==
// Copyright (c) 2014-2020 NetEase, Inc.
// All right reserved.

part of whiteboard_core;

class RoomWBLoginInfo {
  late final String account;
  late final String token;
  late final String channelName;
  late final String platform;
  late final String appKey;
  String? nickname;
  String? url;
  bool? record;
  bool? debug;

  RoomWBLoginInfo(
      {required this.account,
        required this.token,
        required this.channelName,
        required this.platform,
        required this.appKey,
        required this.nickname,
        this.url,
        this.debug,
        this.record,
      });

  RoomWBLoginInfo.fromJson(Map<String, dynamic> json) {
    account = json['account'] as String;
    token = json['token'] as String;
    channelName = json['channelName'] as String;
    platform = json['platform'] as String;
    appKey = json['appKey'] as String;
    nickname = (json['nickname'] ?? '') as String;
    record = (json['record'] ?? false) as bool;
    debug = (json['debug'] ?? false) as bool;
    url = (json['url'] ?? defaultWhiteBoardUrl) as String;
  }

  Map<String, dynamic> toJson() {
    final data =  <String, dynamic>{};
    data['account'] = account;
    data['token'] = token;
    data['channelName'] = channelName;
    data['record'] = record;
    data['debug'] = debug;
    data['platform'] = platform;
    data['appKey'] = appKey;
    data['nickname'] = nickname;
    return data;
  }

  @override
  String toString() =>
      'RoomWBLoginInfo{account: $account, token: $token, channelName: $channelName, platform: $platform, appKey: $appKey, nickname: $nickname, url: $url, record: $record, debug: $debug}';
}

==> whiteboard_core-2.0.0-rc.0.tar.gz: lib/src/model/whiteboard_login_info.dart <==
// Copyright (c) 2014-2020 NetEase, Inc.
// All right reserved.

part of whiteboard_core;

class RoomWBLoginInfo {
  late final String account;
  late final String token;
  late final String channelName;
  late final String platform;
  late final String appKey;
  int? uid; // G2登陆时使用
  String? nickname;
  String? url;
  bool? record;
  bool? debug;

  RoomWBLoginInfo(
      {required this.account,
        required this.token,
        required this.channelName,
        required this.platform,
        required this.appKey,
        required this.nickname,
        this.uid,
        this.url,
        this.debug,
        this.record,
      });

  RoomWBLoginInfo.fromJson(Map<String, dynamic> json) {
    account = json['account'] as String;
    token = json['token'] as String;
    channelName = json['channelName'] as String;
    platform = json['platform'] as String;
    appKey = json['appKey'] as String;
    nickname = (json['nickname'] ?? '') as String;
    record = (json['record'] ?? false) as bool;
    debug = (json['debug'] ?? false) as bool;
    url = (json['url'] ?? defaultWhiteBoardUrlG2) as String;
  }

  Map<String, dynamic> toJson() {
    final data =  <String, dynamic>{};
    data['account'] = account;
    data['token'] = token;
    data['channelName'] = channelName;
    data['record'] = record;
    data['debug'] = debug;
    data['platform'] = platform;
    data['appKey'] = appKey;
    data['nickname'] = nickname;
    data['uid'] = uid;
    return data;
  }

  @override
  String toString() =>
      'RoomWBLoginInfo{account: $account, token: $token, channelName: $channelName, platform: $platform, appKey: $appKey, nickname: $nickname, url: $url, record: $record, debug: $debug}';
}
